/*
 * Copyright (c) 1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project. <http://java.apache.org/>"
 *
 * 4. The names "Java Apache Element Construction Set", "Java Apache ECS" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called
 *    "Java Apache Element Construction Set" nor "Java Apache ECS" appear
 *    in their names without prior written permission of the
 *    Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project. <http://java.apache.org/>"
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */

package org.apache.ecs.storage;

import java.util.Enumeration;
import java.util.Vector;

public class Hash implements java.io.Serializable
{
    private Array keys = new Array();
    private Array elements = new Array();

    public Hash()
    {
    }

    public void setSize(int newSize)
    {
        keys.setSize(newSize);
        elements.setSize(newSize);
    }

    public void setGrow(int growBy)
    {
        keys.setGrow(growBy);
        elements.setGrow(growBy);
    }

    public synchronized void put(String key,Object element)
    {
        try
        {
            if( containsKey(key) )
            {
                elements.add(keys.location(key),element);
            }
            else
            {
                keys.add( key );
                elements.add(element);
            }
        }
        catch(org.apache.ecs.storage.NoSuchObjectException nsoe)
        {
        }
    }

    public synchronized void remove(String key)
    {
        try
        {
            if(containsKey(key))
            {
                elements.remove(keys.location(key));
                elements.remove(elements.location(key));
            }
        }
        catch(org.apache.ecs.storage.NoSuchObjectException nsoe)
        {
        }
    }

    public int size()
    {
        return keys.getCurrentSize();
    }

    public boolean contains(Object element)
    {
        try
        {
            elements.location(element);
            return(true);
        }
        catch(org.apache.ecs.storage.NoSuchObjectException noSuchObject)
        {
            return false;
        }
    }

    public Enumeration keys()
    {
        return keys;
    }

    public boolean containsKey(String key)
    {
        try
        {
            keys.location(key);
        }
        catch(org.apache.ecs.storage.NoSuchObjectException noSuchObject)
        {
            return false;
        }
        return(true);
    }

    public Enumeration elements()
    {
        return elements;
    }

    public Object get(String key)
    {
        try
        {
            if( containsKey(key) )
                return(elements.get(keys.location(key)));
        }
        catch(org.apache.ecs.storage.NoSuchObjectException nsoe)
        {
        }
        return null;
    }
}
